#ifndef NT2_INCLUDE_FUNCTIONS_IS_EQUAL_WITH_EQUAL_NANS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_EQUAL_WITH_EQUAL_NANS_HPP_INCLUDED

#include <nt2/predicates/include/functions/is_equal_with_equal_nans.hpp>

#endif
